@@ -52,9 +52,14 @@ from .general import (
     get_first_non_alphabet,
     is_python,
     punctuate,
+    remove_extra_spaces,
     replace_html_tags,
     replace_multiple_chars,
     set_app_user_model_id,
     similarized,
     sliced_list
+)
+
+from .signal import (
+    Signal
 )
\ No newline at end of file
